@@ -171,7 +171,11 @@ mfxStatus LoaderCtxVPL::SearchDirForLibs(STRING_TYPE searchDir,
     WIN32_FIND_DATAW testFileData;
     DWORD err;
     STRING_TYPE testFileName[NUM_LIB_PREFIXES] = {
+#if defined(__CYGWIN__)
+        searchDir + MAKE_STRING("/cygvpl*.dll"),
+#else
         searchDir + MAKE_STRING("/libvpl*.dll"),
+#endif
     #if defined _M_IX86
         // 32-bit GPU RT names
         searchDir + MAKE_STRING("/libmfx32-gen.dll"),
@@ -1801,7 +1805,7 @@ mfxStatus LoaderCtxVPL::FreeConfigFilters() {
 mfxStatus LoaderCtxVPL::InitDispatcherLog() {
     std::string strLogEnabled, strLogFile;
 
-#if defined(_WIN32) || defined(_WIN64) || defined(__CYGWIN__)
+#if (defined(_WIN32) || defined(_WIN64)) && !defined(__CYGWIN__)
     DWORD err;
 
     char logEnabled[MAX_VPL_SEARCH_PATH] = "";
