@@ -76,10 +76,6 @@ mfxStatus SelectImplementationType(const mfxU32 adapterNum,
         return MFX_ERR_UNSUPPORTED;
     }
 
-    // Filter out non-Intel devices
-    if (dxvaDevice.GetVendorID() != INTEL_VENDOR_ID)
-        return MFX_ERR_UNSUPPORTED;
-
     // obtain card's parameters
     if (pVendorID && pDeviceID) {
         *pVendorID = dxvaDevice.GetVendorID();
@@ -623,18 +619,13 @@ mfxStatus MFXLibraryIterator::GetRegkeyDir(std::wstring &regDir, size_t length,
     mfxStatus sts = MFX_ERR_UNSUPPORTED;
     MFX::MFXLibraryIterator libIterator;
     wchar_t wRegDir[MFX_MAX_DLL_PATH];
-    int numAdapters;
+    int adapterNum = 0;
 
     regDir.clear();
-    DXVA2Device dev;
-    dev.InitDXGI1(0);
-    numAdapters = dev.GetAdapterCount();
-    dev.Close();
-    for (int i = 0; i < numAdapters; i++) {
-        sts = libIterator.Init(MFX_LIB_HARDWARE, MFX_IMPL_VIA_D3D11, i, storageID);
-        if (sts == MFX_ERR_NONE)
-            break;
-    }
+    do {
+        sts = libIterator.Init(MFX_LIB_HARDWARE, MFX_IMPL_VIA_D3D11, adapterNum, storageID);
+        adapterNum++;
+    } while (sts == MFX_ERR_NONE && !libIterator.isIntelAdapter());
     if (sts)
         return MFX_ERR_UNSUPPORTED;
 
